@@ -47,7 +47,10 @@ def parse_annotation(annotation, category_lookup_table):
         print("Warning, unsupported RLE, skipping")
         return None
 
-    if len(segmentation) > 1:
+    if len(segmentation) == 0 and len(annotation["bbox"]) == 4:
+        x, y, w, h = map(int, annotation["bbox"])
+        return dt.make_bounding_box(category["name"], x, y, w, h)
+    elif len(segmentation) > 1:
         print("warning, converting complex coco rle mask to polygon, could take some time")
         mask = rle_decoding(segmentation["counts"], segmentation["size"])
         _labels, external, _internal = find_contours(mask)
@@ -63,15 +66,18 @@ def parse_annotation(annotation, category_lookup_table):
                     break
             paths.append(path)
         return dt.make_complex_polygon(category["name"], paths)
-    path = []
-    points = iter(segmentation[0])
-    while True:
-        try:
-            x, y = next(points), next(points)
-            path.append({"x": x, "y": y})
-        except StopIteration:
-            break
-    return dt.make_polygon(category["name"], path)
+    elif len(segmentation) == 1:
+        path = []
+        points = iter(segmentation[0])
+        while True:
+            try:
+                x, y = next(points), next(points)
+                path.append({"x": x, "y": y})
+            except StopIteration:
+                break
+        return dt.make_polygon(category["name"], path)
+    else:
+        return None
 
 
 def rle_decoding(counts, shape):
